@@ -252,7 +252,7 @@ static inline MagickBooleanType HEICSkipImage(const ImageInfo *image_info,
   return(MagickFalse);
 }
 
-static MagickBooleanType ReadHEICImageByID(const ImageInfo *image_info,
+static MagickBooleanType ReadHEICImageHandle(const ImageInfo *image_info,
   Image *image,struct heif_image_handle *image_handle,
   ExceptionInfo *exception)
 {
@@ -364,6 +364,46 @@ static MagickBooleanType ReadHEICImageByID(const ImageInfo *image_info,
   return(MagickTrue);
 }
 
+static void ReadHEICDepthImage(const ImageInfo *image_info,Image *image,
+  struct heif_image_handle *image_handle,ExceptionInfo *exception)
+{
+  const char
+    *option;
+
+  heif_item_id
+    depth_id;
+
+  int
+    number_images;
+
+  struct heif_error
+    error;
+
+  struct heif_image_handle
+    *depth_handle;
+
+  option=GetImageOption(image_info,"heic:depth-image");
+  if (IsStringTrue(option) == MagickFalse)
+    return;
+  if (heif_image_handle_has_depth_image(image_handle) == 0)
+    return;
+  number_images=heif_image_handle_get_list_of_depth_image_IDs(image_handle,
+    &depth_id,1);
+  if (number_images != 1)
+    return;
+  error=heif_image_handle_get_depth_image_handle(image_handle,depth_id,
+    &depth_handle);
+  if (IsHeifSuccess(image,&error,exception) == MagickFalse)
+    return;
+  AcquireNextImage(image_info,image,exception);
+  if (GetNextImageInList(image) != (Image *) NULL)
+    {
+      image=SyncNextImageInList(image);
+      (void) ReadHEICImageHandle(image_info,image,depth_handle,exception);
+    }
+  heif_image_handle_release(depth_handle);
+}
+
 static Image *ReadHEICImage(const ImageInfo *image_info,
   ExceptionInfo *exception)
 {
@@ -449,7 +489,7 @@ static Image *ReadHEICImage(const ImageInfo *image_info,
       file_data=RelinquishMagickMemory(file_data);
       return(DestroyImageList(image));
     }
-  status=ReadHEICImageByID(image_info,image,image_handle,exception);
+  status=ReadHEICImageHandle(image_info,image,image_handle,exception);
   image_ids=(heif_item_id *) NULL;
   count=(size_t) heif_context_get_number_of_top_level_images(heif_context);
   if ((status != MagickFalse) && (count > 1))
@@ -489,7 +529,7 @@ static Image *ReadHEICImage(const ImageInfo *image_info,
             status=MagickFalse;
             break;
           }
-        status=ReadHEICImageByID(image_info,image,image_handle,exception);
+        status=ReadHEICImageHandle(image_info,image,image_handle,exception);
         if (status == MagickFalse)
           break;
         if (image_info->number_scenes != 0)
@@ -506,38 +546,7 @@ static Image *ReadHEICImage(const ImageInfo *image_info,
       file_data=RelinquishMagickMemory(file_data);
       return(DestroyImageList(image));
     }
-  if (heif_image_handle_has_depth_image(image_handle) != 0)
-    {
-      heif_item_id
-        depth_id;
-
-      int
-        number_images;
-
-      /*
-        Read depth image.
-      */
-      number_images=heif_image_handle_get_list_of_depth_image_IDs(image_handle,
-        &depth_id,1);
-      if (number_images > 0)
-        {
-          struct heif_image_handle
-            *depth_handle;
-
-          error=heif_image_handle_get_depth_image_handle(image_handle,depth_id,
-            &depth_handle);
-          if (IsHeifSuccess(image,&error,exception) != MagickFalse)
-            {
-              AcquireNextImage(image_info,image,exception);
-              if (GetNextImageInList(image) == (Image *) NULL)
-                status=MagickFalse;
-              image=SyncNextImageInList(image);
-              status=ReadHEICImageByID(image_info,image,depth_handle,
-                exception);
-              heif_image_handle_release(depth_handle);
-            }
-       }
-    }
+  ReadHEICDepthImage(image_info,image,image_handle,exception);
   heif_image_handle_release(image_handle);
   if (image_ids != (heif_item_id *) NULL)
     (void) RelinquishMagickMemory(image_ids);
